==> haskell-bifunctors-5.5.4-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bifunctors
version: 5.5.4
id: bifunctors-5.5.4-Bsdhiq0xzEq853rNo1Ntaw
key: bifunctors-5.5.4-Bsdhiq0xzEq853rNo1Ntaw
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/bifunctors/
synopsis: Bifunctors
description:
    Bifunctors.
category: Data, Functors
abi: de5b14069cc175e0da8b31820a551554
exposed: True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biff Data.Bifunctor.Clown
    Data.Bifunctor.Fix Data.Bifunctor.Flip Data.Bifunctor.Functor
    Data.Bifunctor.Join Data.Bifunctor.Joker Data.Bifunctor.Product
    Data.Bifunctor.Sum Data.Bifunctor.TH Data.Bifunctor.Tannen
    Data.Bifunctor.Wrapped
hidden-modules: Data.Bifunctor.TH.Internal Paths_bifunctors
import-dirs: /usr/lib/ghc-8.6.5/site-local/bifunctors-5.5.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/bifunctors-5.5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bifunctors-5.5.4
hs-libraries: HSbifunctors-5.5.4-Bsdhiq0xzEq853rNo1Ntaw
depends:
    base-4.12.0.0 base-orphans-0.8.1-KgdZfvGihTaBPOCyz2z4Jm
    comonad-5.0.5-Jb7dZT99SDmElZXYIEXTJE containers-0.6.0.1
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP template-haskell-2.14.0.0
    th-abstraction-0.2.11.0-DAhuCgi08HTBWsDjm9nrOq transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html: /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bifunctors-5.5.4-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bifunctors
version: 5.5.4
id: bifunctors-5.5.4-Lc9WMZ4So5M6HGQZyTzyTw
key: bifunctors-5.5.4-Lc9WMZ4So5M6HGQZyTzyTw
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/bifunctors/
synopsis: Bifunctors
description:
    Bifunctors.
category: Data, Functors
abi: 983a01b6dafa2c410be0f1d13fce22ac
exposed: True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biff Data.Bifunctor.Clown
    Data.Bifunctor.Fix Data.Bifunctor.Flip Data.Bifunctor.Functor
    Data.Bifunctor.Join Data.Bifunctor.Joker Data.Bifunctor.Product
    Data.Bifunctor.Sum Data.Bifunctor.TH Data.Bifunctor.Tannen
    Data.Bifunctor.Wrapped
hidden-modules: Data.Bifunctor.TH.Internal Paths_bifunctors
import-dirs: /usr/lib/ghc-8.6.5/site-local/bifunctors-5.5.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/bifunctors-5.5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bifunctors-5.5.4
hs-libraries: HSbifunctors-5.5.4-Lc9WMZ4So5M6HGQZyTzyTw
depends:
    base-4.12.0.0 base-orphans-0.8.1-97qBUVoljzsCySOXlyW7Ng
    comonad-5.0.5-DmbDL80vNTBENwSEJV2LS7 containers-0.6.0.1
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP template-haskell-2.14.0.0
    th-abstraction-0.2.11.0-DAhuCgi08HTBWsDjm9nrOq transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html: /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
